@@ -64,7 +64,7 @@ $lsa->upload_document_relevancies_from_file();  # The format of the relevancy
 
 #    Uncomment the following statement if you wish to see the list of all
 #    the documents relevant to each of the queries:
-$lsa->display_doc_relevancies();
+#$lsa->display_doc_relevancies();
 
 $lsa->precision_and_recall_calculator('lsa');
 
