@@ -59,7 +59,7 @@ $vsm->upload_document_relevancies_from_file();  # The format of the relevancy
 
 #    Uncomment the following statement if you wish to see the list of all
 #    the documents relevant to each of the queries:
-$vsm->display_doc_relevancies();
+#$vsm->display_doc_relevancies();
 
 #    Use only one of the following statements.  If you wish to carry out
 #    precision vs. recall analysis for LSA, comment out the first and
